********************************************
* Analysis of US recessions
********************************************

********************************************
* Read in data
********************************************

set more off
clear
cd "$main\data"

use usa_q_transformed_updated.dta,clear

********************************************
* Merge in updated data for this chart
********************************************

preserve
clear
use usa_q_updated_October_2_2015_for_Figure7.dta
gen time = quarterly(date, "YQ")
format time %tq
rename time quarter
drop date
keep quarter gdp ur emp1 pop2
rename gdp gdp_updated
rename ur ur_updated
rename emp1 emp1_updated
rename pop2 pop2_updated
sort quarter
save temp, replace
restore
sort quarter
merge quarter using temp
drop _merge

********************************************
* Keep data 1948Q1 - 2015Q4
********************************************

keep if quarter>=tq(1948q1) & quarter<=tq(2015q4)

********************************************
* Transform data
********************************************

* Use updated variables where applicable:
replace gdp		= gdp_updated
replace ur		= ur_updated
replace emp1	= emp1_updated
replace pop2	= pop2_updated

* Log of real GDP
gen y=gdp
drop logy*
gen logy	= log(y)

gen emp  	= (emp1)
gen logemp = (log(emp))
gen ep		= 100*emp/(pop2/1000)
lab var ep 				"Employment/Population"

********************************************
* Transform data: HP filters
********************************************

* HPF filters: GDP 
* Naming convention:
* For each quarter t, hpf_...`t' is HPF of all data through quarter `t', 
* extended to t+5 assuming assumption of no change in HPF growth rate. 
* Run filter for data through quarter t:

forval quarter = 32(1)190{
gen hpf_y`quarter' = .

hprescott logy if quarter<=`quarter', smooth(1600) stub(H1)
forval i = 1/30 {
	cap replace H1_logy_sm_`i' = 0 if H1_logy_sm_`i'==.
}
gen logy_hpf1600 = H1_logy_sm_1
forval i = 2/30 {
	cap replace logy_hpf1600 = logy_hpf1600 + H1_logy_sm_`i'
}
replace logy_hpf1600=. if logy_hpf1600 ==0
replace hpf_y`quarter' = logy_hpf1600 if quarter<=`quarter'
replace hpf_y`quarter' = hpf_y`quarter'[_n-1] + (hpf_y`quarter'[_n-1]-hpf_y`quarter'[_n-2]) if quarter>`quarter'
drop *hpf1600* *H1*
}

* HPF filters: ln(Emp)  
* Naming convention:
* For each quarter t, hpf_...`t' is HPF of all data through quarter `t', 
* extended to t+5 assuming assumption of no change in HPF growth rate. 
* Run filter for data through quarter t:
forval quarter = 32(1)190 {
gen hpf_emp`quarter' = .
hprescott logemp if quarter<=`quarter', smooth(1600) stub(H1)
forval i = 1/30 {
	cap replace H1_logemp_sm_`i' = 0 if H1_logemp_sm_`i'==.
}
gen logemp_hpf1600 = H1_logemp_sm_1
forval i = 2/30 {
	cap replace logemp_hpf1600 = logemp_hpf1600 + H1_logemp_sm_`i'
}
replace logemp_hpf1600=. if logemp_hpf1600 ==0
replace hpf_emp`quarter' = logemp_hpf1600 if quarter<=`quarter'
replace hpf_emp`quarter' = hpf_emp`quarter'[_n-1] + (hpf_emp`quarter'[_n-1]-hpf_emp`quarter'[_n-2]) if quarter>`quarter'
drop *hpf1600* *H1*
}


* HPF filters: Emp/Pop  
* Naming convention:
* For each quarter t, hpf_...`t' is HPF of all data through quarter `t', 
* extended to t+5 assuming assumption of no change in HPF growth rate. 
* Run filter for data through quarter t:
forval quarter = 80(1)190 {
gen hpf_ep`quarter' = .
hprescott ep if quarter<=`quarter', smooth(1600) stub(H1)
forval i = 1/30 {
	cap replace H1_ep_sm_`i' = 0 if H1_ep_sm_`i'==.
}
gen ep_hpf1600 = H1_ep_sm_1
forval i = 2/30 {
	cap replace ep_hpf1600 = ep_hpf1600 + H1_ep_sm_`i'
}
replace ep_hpf1600=. if ep_hpf1600 ==0
replace hpf_ep`quarter' = ep_hpf1600 if quarter<=`quarter'
replace hpf_ep`quarter' = hpf_ep`quarter'[_n-1] if quarter>`quarter'
drop *hpf1600* *H1*
}

* HPF filters: U rate
* Naming convention:
* For each quarter t, hpf_...`t' is HPF of all data through quarter `t', 
* extended to t+5 assuming assumption of no change in HPF *level*. 
* Run filter for data through quarter t:
gen u=ur
forval quarter = 32(1)190 {
gen hpf_u`quarter' = .
hprescott u if quarter<=`quarter', smooth(1600) stub(H1)
forval i = 1/30 {
	cap replace H1_u_sm_`i' = 0 if H1_u_sm_`i'==.
}
gen u_hpf1600 = H1_u_sm_1
forval i = 2/30 {
	cap replace u_hpf1600 = u_hpf1600 + H1_u_sm_`i'
}
replace u_hpf1600=. if u_hpf1600 ==0
replace hpf_u`quarter' = u_hpf1600 if quarter<=`quarter'
replace hpf_u`quarter' = hpf_u`quarter'[_n-1] if quarter>`quarter'
* replace hpf_u`quarter' = hpf_u`quarter'[_n-1] + (hpf_u`quarter'[_n-1]-hpf_u`quarter'[_n-2]) if quarter>`quarter'
drop *hpf1600* *H1*
}

cd "$main\outputs"

********************************************
* 2007q4:	Dec 2007  June 2009
********************************************

local cty = "USA"
foreach k in 191 {
/* tab quarter if quarter==191
    quarter |      Freq.     Percent        Cum.
------------+-----------------------------------
     2007q4 |          1      100.00      100.00
*/
local quarter = `k'
local y0 = `quarter'-1
local chartstart = `y0'-1

* GDP
preserve
*local title = ""
local title = "Real GDP"
local graphindex = 1
foreach var in y {
twoway (line log`var' hpf_`var'`y0' quarter if (quarter>=`chartstart') & (quarter<=tq(2015q2)), ///
lpattern(solid dash) lcolor(black black) ///
ysize(4) xsize(9.0) ///
legend(off) title("`title'") ///
ylabel(9.5(0.1)9.8) ///
xlabel(, format(%tqCY)) ///
xtitle("") xline(`quarter', lwidth(thick) lcolor(gs9)) ///
saving(`graphindex', replace) )
* Calculations for text related to this figure
gen gap = 100*(log`var' - hpf_`var'`y0')
sum gap if (quarter>=tq(2007q4) & quarter<=tq(2015q2))
clist quarter logy hpf_y`y0' gap if (quarter>=tq(2007q1) & quarter<=tq(2015q4)), noobs
local m1 = r(mean)
}
restore

* U rate
preserve
* Create out of sample forecast
gen lhs		= u - hpf_u`y0'
gen rhs		= logy - hpf_y`y0'
gen L1rhs	= rhs[_n-1]
gen L2rhs	= rhs[_n-2]
reg lhs rhs L1rhs L2rhs if quarter<=`y0', nocons
reg lhs rhs L1rhs L2rhs, nocons
predict hat if quarter>`y0'
replace hat = hat + hpf_u`y0'
* Chart
local title = "Unemployment rate"
local graphindex = 2
foreach var in u {
twoway (line `var' hpf_`var'`y0' quarter if (quarter>=`chartstart') & (quarter<=tq(2015q2)), ///
lpattern(solid dash) lcolor(black black) ///
legend(off) title("`title'") ///
ysize(4) xsize(9.0) ///
xtitle("") xline(`quarter', lwidth(thick) lcolor(gs9)) ///
xlabel(, format(%tqCY)) ///
saving(`graphindex', replace) )
* Calculations for text related to this figure
gen gap = `var' - hpf_`var'`y0'
sum gap if (quarter>=tq(2007q4) & quarter<=tq(2015q2))
local m2 = r(mean)
di(`m2'/`m1')
clist quarter `var' hpf_`var'`y0' gap if (quarter>=tq(2007q1) & quarter<=tq(2015q4)), noobs
}
restore

* Employment 
preserve
* Create out of sample forecast
gen lhs		= logemp - hpf_emp`y0'
gen rhs		= logy - hpf_y`y0'
gen L1rhs	= rhs[_n-1]
gen L2rhs	= rhs[_n-2]
reg lhs rhs L1rhs L2rhs if quarter<=`y0', nocons
lincom _b[rhs] + _b[L1rhs] + _b[L2rhs]
reg lhs rhs L1rhs L2rhs, nocons
lincom _b[rhs] + _b[L1rhs] + _b[L2rhs]
predict hat if quarter>`y0'
replace hat = hat + hpf_emp`y0'
local title = ""
local title = "Employment"
local graphindex = 3
foreach var in emp {
twoway (line log`var' hpf_`var'`y0' quarter if (quarter>=`chartstart') & (quarter<=tq(2015q2)), ///
lpattern(solid dash) lcolor(black black) ///
ysize(4) xsize(9.0) ///
ylabel(11.8(0.1)12) ///
legend(off) title("`title'") ///
xlabel(, format(%tqCY)) ///
xtitle("") xline(`quarter', lwidth(thick) lcolor(gs9)) ///
saving(`graphindex', replace) )
* Calculations for text related to this figure
gen gap = 100*(log`var' - hpf_`var'`y0')
clist quarter log`var' hpf_`var'`y0' gap if (quarter>=tq(2007q1) & quarter<=tq(2015q4)), noobs
}
restore

* E/P Ratio
preserve
local title = ""
local title = "Employment-to-population ratio"
local graphindex = 4
foreach var in ep {
twoway (line `var' hpf_`var'`y0' quarter if (quarter>=`chartstart') & (quarter<=tq(2015q2)), ///
lpattern(solid dash) lcolor(black black) ///
ysize(4) xsize(9.0) ///
legend(off) title("`title'") ///
xlabel(, format(%tqCY)) ///
xtitle("") xline(`quarter', lwidth(thick) lcolor(gs9) ) ///
saving(`graphindex', replace) )
* Calculations for text related to this figure
gen gap = `var' - hpf_`var'`y0'
clist quarter `var' hpf_`var'`y0' gap if (quarter>=tq(2007q1) & quarter<=tq(2015q4)), noobs
}
restore

* Combine charts
graph combine 1.gph 2.gph 3.gph 4.gph, rows(2) cols(2)  saving(Figure_4, replace)
}
erase 1.gph 
erase 2.gph 
erase 3.gph 
erase 4.gph
